@@ -24,7 +24,7 @@ EPS = 2.22044604925e-16
 ZERO = 1e-14
 
 
-def linspace(start, stop, n):
+def main(start, stop, n):
     """linspace(start, stop, n) -> linearly spaced range of n numbers from
     start to stop
 
